@@ -10,20 +10,19 @@
 /* 08Aug2000:	ACR	First version - tested on Linux only.		*/
 /************************************************************************/
 
+#include "stralloc.h"
 #include "hash_core.h"
 #include "admin_core.h"
 #include "noddylib.h"
-#include "../qmail-1.03/subfd.h"
+#include "subfd.h"
+#include "strerr.h"
 
 int main( int argc, char *argv[] )
 {
   if ( argc != 3)
   {
-    substdio_puts(subfderr,"Error: Wrong no. of arguments.\n");
-    substdio_puts(subfderr,"       Usage: ");
-    substdio_puts(subfderr,argv[0]);
-    substdio_puts(subfderr," <username> <alias_to_add>\n");
-    substdio_flush(subfderr);
+    strerr_warn3("Error: Wrong no. of arguments.\n       Usage: ", \
+                                    argv[0]," <username> <alias_to_add>",0);
     return(1);
   }
   else
@@ -32,9 +31,8 @@ int main( int argc, char *argv[] )
     stringclean(argv[2]);
     if (not_hashable(argv[1]) || not_hashable(argv[2]))
     {
-      substdio_puts(subfderr,
-        "Error: Malformed username/alias given (invalid chars or too long).\n");
-      substdio_flush(subfderr);
+      strerr_warn1(
+       "Error: Malformed username/alias given (invalid chars or too long).",0);
       return(1);
     }
     else
