@@ -10,20 +10,19 @@
 /* 25Jul2000:	ACR	First version - tested on Linux only.		*/
 /************************************************************************/
 
+#include "stralloc.h"
 #include "hash_core.h"
 #include "admin_core.h"
 #include "noddylib.h"
-#include "../qmail-1.03/subfd.h"
+#include "subfd.h"
+#include "strerr.h"
 
 int main( int argc, char *argv[] )
 {
   if ( argc != 2)
   {
-    substdio_puts(subfderr,"Error: Wrong no. of arguments.\n");
-    substdio_puts(subfderr,"       Usage: ");
-    substdio_puts(subfderr,argv[0]);
-    substdio_puts(subfderr," <user_to_add>\n");
-    substdio_flush(subfderr);
+    strerr_warn4("Error: Wrong no. of arguments.\n","       Usage: ", \
+                                                argv[0]," <user_to_add>",0);
     return(1);
   }
   else
