@@ -10,29 +10,24 @@
 /* 11Jul2000:	ACR	First version - tested on Linux only.		*/
 /************************************************************************/
 
+#include "stralloc.h"
 #include "hash_core.h"
 #include "noddylib.h"
-#include "../qmail-1.03/substdio.h"
-#include "../qmail-1.03/subfd.h"
-#include "../qmail-1.03/fmt.h"
+#include "substdio.h"
+#include "subfd.h"
+#include "strerr.h"
+#include "fmt.h"
 
 int main( int argc, char *argv[] )
 {
   if ( argc != 2)
-  {
-    substdio_puts(subfderr, "Error: Wrong no. of arguments.\nUsage: ");
-    substdio_puts(subfderr, argv[0]);
-    substdio_puts(subfderr, " <string_to_hash>\n");
-    substdio_flush(subfderr);
-  }
+    strerr_die3x(11,"Error: Wrong no. of arguments.\nUsage: ", \
+                                            argv[0]," <string_to_hash>\n");
   else
   {
     stringclean(argv[1]);
     if (not_hashable(argv[1]))
-    {
-      substdio_puts(subfderr,"Error: Malformed string given (invalid chars or too long).\n");
-      substdio_flush(subfderr);
-    }
+      strerr_die1x(12,"Error: Malformed string given (invalid chars or too long).");
     else
       print_hashdir(argv[1]);
   }
